GenPy: An AST for Python
========================

.. image:: https://gitlab.tiker.net/inducer/genpy/badges/main/pipeline.svg
    :alt: Gitlab Build Status
    :target: https://gitlab.tiker.net/inducer/genpy/commits/main
.. image:: https://github.com/inducer/genpy/workflows/CI/badge.svg?branch=main&event=push
    :alt: Github Build Status
    :target: https://github.com/inducer/genpy/actions?query=branch%3Amain+workflow%3ACI+event%3Apush
.. image:: https://badge.fury.io/py/genpy.png
    :alt: Python Package Index Release Page
    :target: https://pypi.org/project/genpy/

genpy offers a simple abstract syntax tree for Python to allow structured code
generation from Python.

Places on the web related to genpy:

* `Python package index <http://pypi.org/project/genpy>`_ (download releases)
* `Documentation <http://documen.tician.de/genpy>`_ (read how things work)
* `Github <http://github.com/inducer/genpy>`_ (get latest source code, file bugs)

genpy is licensed under the liberal `MIT license
<http://en.wikipedia.org/wiki/MIT_License>`_ and free for commercial, academic,
and private use. All of genpy's dependencies can be automatically installed from
the package index after using::

    pip install genpy
